@@ -2,7 +2,7 @@
 #
 # The MIT License (MIT)
 #
-# Copyright (c) Crossbar.io Technologies GmbH
+# Copyright (c) typedef int GmbH
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -97,34 +97,36 @@ def test_as_future_coroutine(framework):
     # twisted
     if not txaio.using_asyncio:
         return
+    try:
+        from asyncio import coroutine
+    except ImportError:
+        pytest.skip('skipping test: @asyncio.coroutine decorator is removed since Python 3.11')
+    else:
+        errors = []
+        results = []
+        calls = []
 
-    errors = []
-    results = []
-    calls = []
+        @coroutine
+        def method(*args, **kw):
+            calls.append((args, kw))
+            return 42
+        f = txaio.as_future(method, 1, 2, 3, key='word')
 
-    from asyncio import coroutine
+        def cb(x):
+            results.append(x)
 
-    @coroutine
-    def method(*args, **kw):
-        calls.append((args, kw))
-        return 42
-    f = txaio.as_future(method, 1, 2, 3, key='word')
+        def errback(f):
+            errors.append(f)
 
-    def cb(x):
-        results.append(x)
+        txaio.add_callbacks(f, cb, errback)
 
-    def errback(f):
-        errors.append(f)
+        run_once()
+        run_once()
 
-    txaio.add_callbacks(f, cb, errback)
-
-    run_once()
-    run_once()
-
-    assert len(results) == 1
-    assert len(errors) == 0
-    assert results[0] == 42
-    assert calls[0] == ((1, 2, 3), dict(key='word'))
+        assert len(results) == 1
+        assert len(errors) == 0
+        assert results[0] == 42
+        assert calls[0] == ((1, 2, 3), dict(key='word'))
 
 
 def test_as_future_exception(framework):
